Learn R Programming

bayesQR (version 2.1)

print.bayesQR.summary: Prints the contents of bayesQR.summary object to the console

Description

print.bayesQR.summary is an S3 method that prints the content of an S3 object of class bayesQR.summary to the console.

Usage

## S3 method for class 'bayesQR.summary':
print(x, digits=3, ...)

Arguments

x
an output object of the summary.bayesQR function, i.e. an S3 object of class bayesQR.summary.
digits
the number of printed digits of the estimates (default=3).
...
additional arguments that are passed to the generic print function

Value

  • Formatted output of a bayesQR.summary object.

Examples

Run this code
# Simulate data from heteroskedastic regression
set.seed(666)
n <- 200
X <- runif(n=n,min=0,max=10)
y <- 1 + 2*X + rnorm(n=n, mean=0, sd=.6*X)

# Analyze 0.5 quantile using default prior and adaptive lasso
out <- bayesQR(y ~ X, alasso=TRUE, ndraw=5000) 

# Return Bayes estimates and credible intervals 
sum <- summary(out, burnin=1000)

# Print the bayesQR.summary object
sum

Run the code above in your browser using DataLab